==> openGion7.0.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE36S.sql <==
/****************************************************************************/
/* GE36 ( ﾊﾞｯﾁ送信ｴﾗｰﾃｰﾌﾞﾙ )                                                */
/*                                                                          */
/* Created : 2017/07/18 08:42:12                                            */
/****************************************************************************/

CREATE TABLE GE36 (
   PARA_KEY     varchar           (    9 )                  NOT NULL            /*  10 ﾊﾟﾗﾒｰﾀｷｰ     */
 , SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  20 ｼｽﾃﾑID       */
 , ERRMSG       varchar           ( 4000 )                                      /*  30 ｴﾗｰﾒｯｾｰｼﾞ    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion7.0.5.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE36S.sql <==
/****************************************************************************/
/* GE36 ( ﾊﾞｯﾁ送信ｴﾗｰﾃｰﾌﾞﾙ )                                                */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE36 (
   PARA_KEY     varchar           (    9 )                  NOT NULL            /*  10 ﾊﾟﾗﾒｰﾀｷｰ     */
 , SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  20 ｼｽﾃﾑID       */
 , ERRMSG       varchar           ( 4000 )                                      /*  30 ｴﾗｰﾒｯｾｰｼﾞ    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
